about summary refs log tree commit diff stats
path: root/035compute_segment_address.cc
diff options
context:
space:
mode:
authorKartik Agaram <vc@akkartik.com>2020-09-27 22:05:11 -0700
committerKartik Agaram <vc@akkartik.com>2020-09-27 22:05:11 -0700
commiteee09a56076f40beabea1f9f677d7d6463265bb0 (patch)
treec3bc8d12e48b671d36f31befb5ea9e07486f13d0 /035compute_segment_address.cc
parentf068bda98e0218df6b551a6cd8e5520255866308 (diff)
downloadmu-eee09a56076f40beabea1f9f677d7d6463265bb0.tar.gz
6887
subx.md distinguishes between operands and arguments. Let's use that terminology
more consistently in the sources.
Diffstat (limited to '035compute_segment_address.cc')
-rw-r--r--035compute_segment_address.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/035compute_segment_address.cc b/035compute_segment_address.cc
index c6a1b441..5c627a7b 100644
--- a/035compute_segment_address.cc
+++ b/035compute_segment_address.cc
@@ -61,9 +61,9 @@ uint32_t num_bytes(const line& inst) {
 }
 
 int size_of(const word& w) {
-  if (has_operand_metadata(w, "disp32") || has_operand_metadata(w, "imm32"))
+  if (has_argument_metadata(w, "disp32") || has_argument_metadata(w, "imm32"))
     return 4;
-  else if (has_operand_metadata(w, "disp16"))
+  else if (has_argument_metadata(w, "disp16"))
     return 2;
   // End size_of(word w) Special-cases
   else
@@ -79,7 +79,7 @@ int size_of(const word& w) {
 //:   (num_bytes).
 //:
 //: Decision: compute segment addresses before expanding labels, by being
 //: aware in this layer of certain operand types that will eventually occupy
 //: multiple bytes.
 //:
 //: The layer to expand labels later hooks into num_bytes() to teach this
@@ -79,7 +79,7 @@ int size_of(const word& w) {
 //:
 //: Decision: compute segment addresses before expanding labels, by being
-//: aware in this layer of certain operand types that will eventually occupy
+//: aware in this layer of certain argument types that will eventually occupy
 //: multiple bytes.
 //: